@@ -38,6 +38,9 @@ def Kronecker(system, u_, vs, lambda_=None, linf_constant = None):
 
     rabinowitsch_system = [rabinowitsch_R(f) for f in system] + [rabinowitsch_R(linf)]
     if lambda_:
+        if (MPolynomialIdeal(rabinowitsch_R, rabinowitsch_system + [lambda_*(1-lambda_*x0)]).dimension() > 0):
+            print(f"{bcolors.WARNING}Warning:{bcolors.ENDC} H has a point with vanishing partial derivatives.")
+            print(f"{bcolors.WARNING}Warning:{bcolors.ENDC} Any minimal critical point computations performed may be incorrect.")
         rabinowitsch_system += [1-lambda_*x0]
     n = len(rabinowitsch_R.gens())
     #print("Rabinowitsch System", rabinowitsch_system)
